@@ -3,8 +3,8 @@
 use core::ops::{Add, AddAssign, Sub, SubAssign};
 
 use crate::{
-    traits::{Contains, Intersection, Lerp, UnitTypes},
-    Point2, Point3, Rect, Size2, Union, Unit, Vector2,
+    traits::{Contains, Intersection, Lerp},
+    Point2, Point3, Rect, Size2, Union, Unit, UnitTypes, Vector2,
 };
 
 /// 2D axis-aligned box represented as "min" and "max" points.
@@ -48,6 +48,12 @@ crate::impl_as_tuple!(Box3 {
 });
 
 impl<T: Unit> Box2<T> {
+    /// Zero-sized box.
+    pub const ZERO: Self = Self {
+        min: Point2::ZERO,
+        max: Point2::ZERO,
+    };
+
     /// Create from [`Rect`].
     ///
     /// Note: This may lose precision due to floating point arithmetic.
@@ -72,7 +78,7 @@ impl<T: Unit> Box2<T> {
     #[must_use]
     pub fn from_size(size: Size2<T>) -> Self {
         Box2 {
-            min: Point2::zero(),
+            min: Point2::ZERO,
             max: size.to_vector().to_point(),
         }
     }
@@ -145,7 +151,7 @@ impl<T: Unit> Box2<T> {
         let (mut min, mut max) = if let Some(first) = points.next() {
             (first, first)
         } else {
-            return Box2::zero();
+            return Box2::ZERO;
         };
 
         for point in points {
@@ -226,7 +232,7 @@ impl<T: Unit> Box2<T> {
     #[inline]
     #[must_use]
     pub fn center(&self) -> Point2<T> {
-        let v = (self.max - self.min) / Vector2::two();
+        let v = (self.max - self.min) / (Vector2::ONE + Vector2::ONE);
         self.min + v
     }
 
@@ -243,13 +249,6 @@ impl<T: Unit> Box2<T> {
     pub fn area(&self) -> T::Scalar {
         self.size().area()
     }
-
-    /// Create a zero-sized box.
-    #[inline]
-    #[must_use]
-    pub fn zero() -> Self {
-        Box2::new(Point2::zero(), Point2::zero())
-    }
 }
 
 impl<T: Unit> From<Box2<T>> for Rect<T> {
@@ -388,6 +387,8 @@ where
 mod tests {
     use approx::assert_abs_diff_eq;
 
+    use crate::vec2;
+
     use super::*;
 
     type Box2 = super::Box2<f32>;
@@ -397,20 +398,28 @@ mod tests {
     #[test]
     fn from_rect() {
         let r = Rect::new((10.0, 12.0).into(), (5.0, 6.0).into());
-        let b = Box2::from(r);
+        let b = Box2::from_rect(r);
         let b2 = Box2::from_origin_and_size((10.0, 12.0).into(), (5.0, 6.0).into());
         assert_abs_diff_eq!(b, b2);
         assert_abs_diff_eq!(b.min, Point2::new(10.0, 12.0));
         assert_abs_diff_eq!(b.max, Point2::new(15.0, 18.0));
 
         let b3 = Box2::from_size((10.0, 12.0).into());
-        assert_abs_diff_eq!(b3.min, Point2::zero());
+        assert_abs_diff_eq!(b3.min, Point2::ZERO);
         assert_abs_diff_eq!(b3.max, Point2::new(10.0, 12.0));
 
         let r2 = b2.to_rect();
         assert_abs_diff_eq!(r2, r);
     }
 
+    #[test]
+    fn from_array() {
+        let array = [Point2::ZERO, Point2::ONE];
+        let b = Box2::from_array(array);
+        assert_eq!(b.min, Point2::ZERO);
+        assert_eq!(b.max, Point2::ONE);
+    }
+
     #[test]
     fn cast() {
         let mut b = Box2::new(Point2::new(0.5, 0.5), Point2::new(1.0, 1.0));
@@ -424,11 +433,12 @@ mod tests {
 
     #[test]
     fn from_points() {
-        let b = Box2::from_points(core::iter::empty());
-        assert_eq!(b, Box2::zero());
+        let empty: [Point2<_>; 0] = [];
+        let b = Box2::from_points(empty);
+        assert_eq!(b, Box2::ZERO);
 
         let b =
-            Box2::from_points([(0.0, 1.0), (1.0, 2.0), (0.0, 2.0), (0.5, 0.5)].map(Point2::from));
+            Box2::from_points([(0.1, 1.0), (1.0, 2.0), (0.0, 2.0), (0.5, 0.5)].map(Point2::from));
 
         assert_abs_diff_eq!(
             b,
@@ -493,7 +503,7 @@ mod tests {
             min: (1.0, 2.0).into(),
             max: (2.0, 3.0).into(),
         };
-        let b2 = b.translate(Vector2::new(1.0, 0.5));
+        let b2 = b.translate(vec2!(1.0, 0.5));
         assert_abs_diff_eq!(
             b2,
             Box2 {
@@ -503,10 +513,10 @@ mod tests {
         );
 
         let mut b3 = b;
-        b3 += Vector2::new(1.0, 0.5);
+        b3 += vec2![1.0, 0.5];
         assert_abs_diff_eq!(b3, b2);
-        assert_abs_diff_eq!(b3 - Vector2::new(1.0, 0.5), b);
-        b3 -= Vector2::new(1.0, 0.5);
+        assert_abs_diff_eq!(b3 - vec2![1.0, 0.5], b);
+        b3 -= vec2![1.0, 0.5];
         assert_abs_diff_eq!(b3, b);
     }
 
@@ -538,7 +548,7 @@ mod tests {
         assert_abs_diff_eq!(b.size().area(), b.area());
         assert_abs_diff_eq!(b.area(), 4.0);
 
-        assert_abs_diff_eq!(Box2::zero().area(), 0.0);
+        assert_abs_diff_eq!(Box2::ZERO.area(), 0.0);
     }
 
     #[test]
@@ -682,8 +692,8 @@ mod tests {
             }
         );
 
-        assert_abs_diff_eq!(b.union(Box2::zero()), b);
-        assert_abs_diff_eq!(Box2::zero().union(b), b);
+        assert_abs_diff_eq!(b.union(Box2::ZERO), b);
+        assert_abs_diff_eq!(Box2::ZERO.union(b), b);
     }
 
     #[test]
